pub struct RustBuilder<'config> { /* private fields */ }Expand description
AST builder for the Rust language.
RustBuilder is responsible for parsing Rust source code and constructing
an Abstract Syntax Tree (AST). It uses a Pratt parser to handle operator
precedence in expressions and supports all Rust syntax features.
Implementations
Sourceimpl<'config> RustBuilder<'config>
impl<'config> RustBuilder<'config>
Sourcepub fn build_generics_and_where(
&self,
node: RedNode<'_, RustLanguage>,
source: &SourceText,
) -> Result<Option<Generics>, OakError>
pub fn build_generics_and_where( &self, node: RedNode<'_, RustLanguage>, source: &SourceText, ) -> Result<Option<Generics>, OakError>
Builds generic parameters and where clauses from a node’s children.
Sourceimpl<'config> RustBuilder<'config>
impl<'config> RustBuilder<'config>
Sourcepub const fn new(config: &'config RustLanguage) -> Self
pub const fn new(config: &'config RustLanguage) -> Self
Creates a new RustBuilder with the given configuration.