RustTokenType

Enum RustTokenType 

pub enum RustTokenType {
Show 145 variants As, Break, Const, Continue, Crate, Else, Enum, Extern, False, Fn, For, If, Impl, In, Let, Loop, Match, Mod, Move, Mut, Pub, Ref, Return, SelfLower, SelfUpper, Static, Struct, Super, Trait, True, Type, Unsafe, Use, Where, While, Abstract, Become, Box, Do, Final, Macro, Override, Priv, Typeof, Unsized, Virtual, Yield, Async, Await, Dyn, Try, Union, Raw, IntegerLiteral, FloatLiteral, StringLiteral, CharLiteral, ByteLiteral, ByteStringLiteral, RawStringLiteral, BoolLiteral, Identifier, Lifetime, LeftParen, RightParen, LeftBrace, RightBrace, LeftBracket, RightBracket, Semicolon, Comma, Dot, DotDot, DotDotDot, DotDotEq, Colon, DoubleColon, PathSep, Question, At, Hash, Dollar, Plus, Minus, Star, Slash, Percent, Caret, Ampersand, Pipe, Tilde, Bang, Eq, Lt, Gt, LessThan, GreaterThan, EqEq, Ne, Le, Ge, LessEq, GreaterEq, AndAnd, OrOr, LeftShift, RightShift, Shl, Shr, PlusEq, MinusEq, StarEq, SlashEq, PercentEq, CaretEq, AndEq, OrEq, ShlEq, ShrEq, LeftShiftEq, RightShiftEq, Underscore, Assign, PlusAssign, MinusAssign, StarAssign, SlashAssign, PercentAssign, AmpAssign, PipeAssign, CaretAssign, ShlAssign, ShrAssign, Arrow, FatArrow, Space, Newline, Whitespace, LineComment, BlockComment, DocComment, PlusPlus, MinusMinus, Eof, Error,
}
Rust token types.

Variants



As

as



Break

break



Const

const



Continue

continue



Crate

crate



Else

else



Enum

enum



Extern

extern



False

false



Fn

fn



For

for



If

if



Impl

impl



In

in



Let

let



Loop

loop



Match

match



Mod

mod



Move

move



Mut

mut



Pub

pub



Ref

ref



Return

return



SelfLower

self



SelfUpper

Self



Static

static



Struct

struct



Super

super



Trait

trait



True

true



Type

type



Unsafe

unsafe



Use

use



Where

where



While

while



Abstract

abstract



Become

become



Box

box



Do

do



Final

final



Macro

macro



Override

override



Priv

priv



Typeof

typeof



Unsized

unsized



Virtual

virtual



Yield

yield



Async

async



Await

await



Dyn

dyn



Try

try



Union

union



Raw

raw



IntegerLiteral

Integer literal



FloatLiteral

Float literal



StringLiteral

String literal



CharLiteral

Char literal



ByteLiteral

Byte literal



ByteStringLiteral

Byte string literal



RawStringLiteral

Raw string literal



BoolLiteral

Bool literal



Identifier

Identifier



Lifetime

Lifetime



LeftParen

(



RightParen

)



LeftBrace

{



RightBrace

}



LeftBracket

[



RightBracket

]



Semicolon

;



Comma

,



Dot

.



DotDot

..



DotDotDot

...



DotDotEq

..=



Colon

:



DoubleColon

::



PathSep

Path separator



Question

?



At

@



Hash

#



Dollar

$



Plus

+



Minus

-



Star

*



Slash

/



Percent

%



Caret

^



Ampersand

&



Pipe

|



Tilde

~



Bang

!



Eq

=



Lt

<



Gt

>



LessThan

<



GreaterThan

>



EqEq

==



Ne

!=



Le

<=



Ge

>=



LessEq

<=



GreaterEq

>=



AndAnd

&&



OrOr

||



LeftShift

<<



RightShift

>>



Shl

<<



Shr

>>



PlusEq

+=



MinusEq

-=



StarEq

*=



SlashEq

/=



PercentEq

%=



CaretEq

^=



AndEq

&=



OrEq

|=



ShlEq

<<=



ShrEq

>>=



LeftShiftEq

<<=



RightShiftEq

>>=



Underscore

_



Assign

=



PlusAssign

+=



MinusAssign

-=



StarAssign

*=



SlashAssign

/=



PercentAssign

%=



AmpAssign

&=



PipeAssign

|=



CaretAssign

^=



ShlAssign

<<=



ShrAssign

>>=



Arrow

->



FatArrow

=>



Space

Space



Newline

Newline



Whitespace

Whitespace



LineComment

Line comment



BlockComment

Block comment



DocComment

Doc comment



PlusPlus

++



MinusMinus

--



Eof

End of stream



Error

Error

Implementations

Source

impl RustTokenType

pub fn is_literal(&self) -> bool

Returns true if the token is a literal.